@@ -1,10 +1,12 @@
-mod fixtures;
+use std::process::Command;
 
 use assert_cmd::prelude::*;
 use clap::{crate_name, crate_version, ValueEnum};
 use clap_complete::Shell;
-use fixtures::Error;
-use std::process::Command;
+
+mod fixtures;
+
+use crate::fixtures::Error;
 
 #[test]
 /// Show help and exit.
