@@ -1,24 +1,26 @@
-mod fixtures;
-mod utils;
+use std::process::{Command, Stdio};
 
-use fixtures::{server, Error, TestServer, DEEPLY_NESTED_FILE, DIRECTORIES};
 use pretty_assertions::{assert_eq, assert_ne};
 use rstest::rstest;
 use select::document::Document;
-use std::process::{Command, Stdio};
-use utils::get_link_from_text;
-use utils::get_link_hrefs_with_prefix;
 
-#[rstest(
-    input,
-    expected,
-    case("", "/"),
-    case("/dira", "/dira/"),
-    case("/dirb/", "/dirb/"),
-    case("/very/deeply/nested", "/very/deeply/nested/")
-)]
+mod fixtures;
+mod utils;
+
+use crate::fixtures::{server, Error, TestServer, DEEPLY_NESTED_FILE, DIRECTORIES};
+use crate::utils::{get_link_from_text, get_link_hrefs_with_prefix};
+
+#[rstest]
+#[case("", "/")]
+#[case("/dira", "/dira/")]
+#[case("/dirb/", "/dirb/")]
+#[case("/very/deeply/nested", "/very/deeply/nested/")]
 /// Directories get a trailing slash.
-fn index_gets_trailing_slash(server: TestServer, input: &str, expected: &str) -> Result<(), Error> {
+fn index_gets_trailing_slash(
+    server: TestServer,
+    #[case] input: &str,
+    #[case] expected: &str,
+) -> Result<(), Error> {
     let resp = reqwest::blocking::get(server.url().join(input)?)?;
     assert!(resp.url().as_str().ends_with(expected));
 
